@@ -36,7 +36,17 @@ if TYPE_CHECKING:
     from sphinx.ext.autodoc import Options
 
 _LOGGER = logging.getLogger(__name__)
-_PYDATA_ANNOTS_TYPING = {"Any", "AnyStr", "Callable", "ClassVar", "Literal", "NoReturn", "Optional", "Tuple", "Union"}
+_PYDATA_ANNOTS_TYPING = {
+    "Any",
+    "AnyStr",
+    "Callable",
+    "ClassVar",
+    "Literal",
+    "NoReturn",
+    "Optional",
+    "Tuple",
+    *({"Union"} if sys.version_info < (3, 14) else set()),
+}
 _PYDATA_ANNOTS_TYPES = {
     *("AsyncGeneratorType", "BuiltinFunctionType", "BuiltinMethodType"),
     *("CellType", "ClassMethodDescriptorType", "CoroutineType"),
@@ -246,8 +256,10 @@ def format_annotation(annotation: Any, config: Config, *, short_literals: bool =
     formatted_args: str | None = ""
 
     always_use_bars_union: bool = getattr(config, "always_use_bars_union", True)
-    is_bars_union = full_name == "types.UnionType" or (
-        always_use_bars_union and type(annotation).__qualname__ == "_UnionGenericAlias"
+    is_bars_union = (
+        (sys.version_info >= (3, 14) and full_name == "typing.Union")
+        or full_name == "types.UnionType"
+        or (always_use_bars_union and type(annotation).__qualname__ == "_UnionGenericAlias")
     )
     if is_bars_union:
         full_name = ""
@@ -588,7 +600,7 @@ def backfill_type_hints(obj: Any, name: str) -> dict[str, Any]:  # noqa: C901, P
         return {}
 
     try:
-        type_comment = obj_ast.type_comment
+        type_comment = obj_ast.type_comment  # type: ignore[attr-defined]
     except AttributeError:
         return {}
 
@@ -610,7 +622,7 @@ def backfill_type_hints(obj: Any, name: str) -> dict[str, Any]:  # noqa: C901, P
     if comment_returns:
         rv["return"] = comment_returns
 
-    args = load_args(obj_ast)
+    args = load_args(obj_ast)  # type: ignore[arg-type]
     comment_args = split_type_comment_args(comment_args_str)
     is_inline = len(comment_args) == 1 and comment_args[0] == "..."
     if not is_inline:
